"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb

from freeclimb.model.sms_toll_free_campaign import SMSTollFreeCampaign  # noqa: E501

class TestSMSTollFreeCampaign(unittest.TestCase):
    """SMSTollFreeCampaign unit test stubs"""

    def setUp(self):
        self.model = SMSTollFreeCampaign(
            account_id="",
            campaign_id="",
            use_case="",
            registration_status="UNREGISTERED",
            date_created="",
            date_updated="",
            revision=1,
        )
    
    def test_account_id(self):
        """Test SMSTollFreeCampaign.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

    def test_campaign_id(self):
        """Test SMSTollFreeCampaign.campaign_id"""
        self.model.campaign_id = "TEST_STRING"
        assert self.model.get("campaign_id") == "TEST_STRING"

    def test_use_case(self):
        """Test SMSTollFreeCampaign.use_case"""
        self.model.use_case = "TEST_STRING"
        assert self.model.get("use_case") == "TEST_STRING"

    def test_registration_status(self):
        """Test SMSTollFreeCampaign.registration_status"""
        self.model.registration_status = "UNREGISTERED"
        assert self.model.get("registration_status") == "UNREGISTERED"
        self.model.registration_status = "INITIATED"
        assert self.model.get("registration_status") == "INITIATED"
        self.model.registration_status = "PENDING"
        assert self.model.get("registration_status") == "PENDING"
        self.model.registration_status = "DECLINED"
        assert self.model.get("registration_status") == "DECLINED"
        self.model.registration_status = "REGISTERED"
        assert self.model.get("registration_status") == "REGISTERED"

    def test_registration_status_throws_on_invalid_enum(self):
        with pytest.raises(Exception) as info:
            self.model.registration_status = "INVALID_ENUM"
        exception_raised = info.value
        assert exception_raised.__class__.__name__ == freeclimb.ApiValueError.__name__
        
    def test_date_created(self):
        """Test SMSTollFreeCampaign.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test SMSTollFreeCampaign.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test SMSTollFreeCampaign.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1


if __name__ == '__main__':
    unittest.main()